@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  */
 
 #include "config.h"
@@ -137,6 +137,7 @@ typedef struct _TotemEmbedded {
 	GtkWidget * fs_window;
 
 	/* Error */
+	GError *error;
 
 	guint type : 3; /* TotemPluginType */
 
@@ -172,8 +173,7 @@ static void totem_embedded_init (TotemEmbedded *emb) { }
 static gboolean totem_embedded_do_command (TotemEmbedded *emb, const char *command, GError **err);
 static gboolean totem_embedded_push_parser (gpointer data);
 static gboolean totem_embedded_play (TotemEmbedded *embedded, GError **error);
-
-static void totem_embedded_clear_playlist (TotemEmbedded *embedded);
+static void totem_embedded_set_logo_by_name (TotemEmbedded *embedded, const char *name);
 
 static void totem_embedded_update_menu (TotemEmbedded *emb);
 static void on_open1_activate (GtkButton *button, TotemEmbedded *emb);
@@ -189,6 +189,7 @@ enum {
 	START_STREAM,
 	STOP_STREAM,
 	SIGNAL_TICK,
+	PROPERTY_CHANGE,
 	LAST_SIGNAL
 };
 
@@ -257,6 +258,14 @@ static void totem_embedded_class_init (TotemEmbeddedClass *klass)
 				NULL /* accu */, NULL /* accu data */,
 				totempluginviewer_marshal_VOID__UINT_UINT_STRING,
 				G_TYPE_NONE, 3, param_types);
+	signals[PROPERTY_CHANGE] =
+		g_signal_new ("property-change",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      0 /* class offset */,
+			      NULL /* accu */, NULL /* accu data */,
+			      totempluginviewer_marshal_VOID__STRING_BOXED,
+			      G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_VALUE);
 }
 
 static void
@@ -279,21 +288,40 @@ static void
 totem_embedded_save_volume (TotemEmbedded *emb, double volume)
 {
 	GConfClient *gc;
+	GValue value = { 0, };
 
 	gc = gconf_client_get_default ();
 	gconf_client_set_int (gc, GCONF_PREFIX"/volume", (int) (volume * 100.0), NULL);
 	g_object_unref (G_OBJECT (gc));
+
+	g_value_init (&value, G_TYPE_DOUBLE);
+	g_value_set_double (&value, volume);
+	g_signal_emit (emb, signals[PROPERTY_CHANGE], 0,
+		       TOTEM_PROPERTY_VOLUME,
+		       &value);
 }
 
 static void
 totem_embedded_set_error (TotemEmbedded *emb,
-			  char *primary,
+			  int code,
 			  char *secondary)
 {
-	/* FIXME */
-	g_message ("totem_embedded_set_error: '%s', '%s'", primary, secondary);
+	emb->error = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
+				  code,
+				  secondary);
+	g_message ("totem_embedded_set_error: '%s'", secondary);
 }
 
+static gboolean
+totem_embedded_set_error_logo (TotemEmbedded *embedded,
+			       GError *error)
+{
+	g_message ("totem_embedded_set_error_logo called by browser plugin");
+	totem_embedded_set_logo_by_name (embedded, "image-missing");
+	return TRUE;
+}
+
+
 static void
 totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 {
@@ -388,7 +416,7 @@ totem_embedded_set_logo_by_name (TotemEmbedded *embedded,
 
 	totem_embedded_set_state (embedded, TOTEM_STATE_STOPPED);
 
-	if (embedded->audioonly != FALSE)
+	if (embedded->audioonly != FALSE || embedded->hidden != FALSE)
 		return;
 
 	theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (embedded->window));
@@ -454,23 +482,19 @@ totem_embedded_open_internal (TotemEmbedded *emb,
 	if (retval == FALSE)
 	{
 		GError *errint;
-		char *primary;
 
 		/* FIXME we haven't even started sending yet! */
 		//g_signal_emit (emb, signals[STOP_STREAM], 0);
 
 		totem_embedded_set_state (emb, TOTEM_STATE_STOPPED);
-		totem_embedded_set_logo_by_name (emb, "image-missing");
+		totem_embedded_set_error_logo (emb, NULL);
 
 		errint = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
 				      TOTEM_EMBEDDED_OPEN_FAILED,
 				      _("Totem could not play '%s'"),
 				     emb->current_uri);
 
-		//FIXME disp = gnome_vfs_unescape_string_for_display (totem->mrl); ?
-		primary = g_strdup_printf(_("Totem could not play '%s'"), emb->current_uri);
-		totem_embedded_set_error (emb, primary, err->message);;
-		g_free (primary);
+		totem_embedded_set_error (emb, err->code, err->message);;
 
 		g_propagate_error (error, err);
 
@@ -498,7 +522,12 @@ totem_embedded_play (TotemEmbedded *emb,
 {
 	GError *err = NULL;
 
-	g_return_val_if_fail (emb->current_uri != NULL, FALSE);
+	if (emb->current_uri == NULL) {
+		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
+		g_signal_emit (emb, signals[BUTTON_PRESS], 0,
+			       gtk_get_current_event_time (), 0);
+		return TRUE;
+	}
 
 	totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
 
@@ -530,6 +559,11 @@ totem_embedded_stop (TotemEmbedded *emb,
 	totem_embedded_set_state (emb, TOTEM_STATE_STOPPED);
 	bacon_video_widget_stop (emb->bvw);
 
+	g_signal_emit (emb, signals[SIGNAL_TICK], 0,
+		       (guint32) 0,
+		       (guint32) 0,
+		       totem_states[emb->state]);
+
 	return TRUE;
 }
 
@@ -584,15 +618,6 @@ totem_embedded_set_href (TotemEmbedded *embedded,
 	return TRUE;
 }
 
-static gboolean
-totem_embedded_set_error_logo (TotemEmbedded *embedded,
-			       GError *error)
-{
-	g_message ("totem_embedded_set_error_logo called by browser plugin");
-	totem_embedded_set_logo_by_name (embedded, "image-missing");
-	return TRUE;
-}
-
 static gboolean
 totem_embedded_set_volume (TotemEmbedded *embedded,
 			   gdouble volume,
@@ -600,6 +625,7 @@ totem_embedded_set_volume (TotemEmbedded *embedded,
 {
 	g_message ("totem_embedded_set_volume: %f", volume);
 	bacon_video_widget_set_volume (embedded->bvw, volume);
+	totem_embedded_save_volume (embedded, volume);
 	return TRUE;
 }
 
@@ -937,15 +963,126 @@ totem_embedded_set_uri (TotemEmbedded *emb,
 	emb->stream_uri = NULL;
 }
 
+static void
+totem_pl_item_free (gpointer data, gpointer user_data)
+{
+	TotemPlItem *item = (TotemPlItem *) data;
+
+	if (!item)
+		return;
+	g_free (item->uri);
+	g_free (item);
+}
+
+static gboolean
+totem_embedded_clear_playlist (TotemEmbedded *embedded, GError *error)
+{
+	g_list_foreach (embedded->playlist, (GFunc) totem_pl_item_free, NULL);
+	g_list_free (embedded->playlist);
+
+	embedded->playlist = NULL;
+	embedded->current = NULL;
+	embedded->num_items = 0;
+
+	totem_embedded_set_uri (embedded, NULL, NULL, FALSE);
+
+	bacon_video_widget_close (embedded->bvw);
+
+	return TRUE;
+}
+
+static gboolean
+totem_embedded_add_item (TotemEmbedded *embedded, const char *uri, GError *error)
+{
+	TotemPlItem *item;
+
+	g_message ("totem_embedded_add_item: %s", uri);
+
+	item = g_new0 (TotemPlItem, 1);
+	item->uri = g_strdup (uri);
+	item->duration = -1;
+	item->starttime = -1;
+
+	embedded->playlist = g_list_append (embedded->playlist, item);
+	embedded->num_items++;
+
+	if (embedded->current_uri == NULL) {
+		embedded->current = embedded->playlist;
+		totem_embedded_set_uri (embedded,
+					(const char *) uri,
+					embedded->base_uri /* FIXME? */,
+					FALSE);
+		totem_embedded_open_internal (embedded, FALSE, NULL /* FIXME */);
+	}
+
+	return TRUE;
+}
+
+static gboolean
+totem_embedded_set_fullscreen (TotemEmbedded *emb,
+			       gboolean fullscreen_enabled,
+			       GError **error)
+{
+	GValue value = { 0, };
+	GtkAction *fs_action;
+	
+	fs_action = GTK_ACTION (gtk_builder_get_object 
+				(emb->menuxml, "fullscreen1"));
+
+	if (totem_fullscreen_is_fullscreen (emb->fs) == fullscreen_enabled)
+		return TRUE;
+
+	g_message ("totem_embedded_set_fullscreen: %d", fullscreen_enabled);
+
+	if (fullscreen_enabled == FALSE) {
+		GtkWidget * container;
+		container = GTK_WIDGET (gtk_builder_get_object (emb->xml,
+								"video_box"));
+
+		totem_fullscreen_set_fullscreen (emb->fs, FALSE);
+		gtk_widget_reparent (GTK_WIDGET (emb->bvw), container);
+		gtk_widget_hide_all (emb->fs_window);
+
+		gtk_action_set_sensitive (fs_action, TRUE);
+	} else {
+		GdkRectangle rect;
+		int monitor;
+
+		/* Move the fullscreen window to the screen where the
+		 * video widget currently is */
+		monitor = gdk_screen_get_monitor_at_window (gtk_widget_get_screen (GTK_WIDGET (emb->bvw)),
+							    GTK_WIDGET (emb->bvw)->window);
+		gdk_screen_get_monitor_geometry (gtk_widget_get_screen (GTK_WIDGET (emb->bvw)),
+						 monitor, &rect);
+		gtk_window_move (GTK_WINDOW (emb->fs_window), rect.x, rect.y);
+
+		gtk_widget_reparent (GTK_WIDGET (emb->bvw), emb->fs_window);
+		bacon_video_widget_set_fullscreen (emb->bvw, TRUE);
+		gtk_window_fullscreen (GTK_WINDOW (emb->fs_window));
+		totem_fullscreen_set_fullscreen (emb->fs, TRUE);
+		gtk_widget_show_all (emb->fs_window);
+
+		gtk_action_set_sensitive (fs_action, FALSE);
+	}
+
+	g_value_init (&value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&value, fullscreen_enabled);
+	g_signal_emit (emb, signals[PROPERTY_CHANGE], 0,
+		       TOTEM_PROPERTY_ISFULLSCREEN,
+		       &value);
+
+	return TRUE;
+}
+
 static gboolean
 totem_embedded_open_uri (TotemEmbedded *emb,
 			 const char *uri,
 			 const char *base_uri,
 			 GError **error)
 {
-	totem_embedded_clear_playlist (emb);
+	g_message ("totem_embedded_open_uri: uri %s base_uri: %s", uri, base_uri);
 
-	bacon_video_widget_close (emb->bvw);
+	totem_embedded_clear_playlist (emb, NULL);
 
 	totem_embedded_set_uri (emb, uri, base_uri, FALSE);
 
@@ -958,9 +1095,9 @@ totem_embedded_open_stream (TotemEmbedded *emb,
 			    const char *base_uri,
 			    GError **error)
 {
-	totem_embedded_clear_playlist (emb);
+	g_message ("totem_embedded_open_stream called: uri %s, base_uri: %s", uri, base_uri);
 
-	bacon_video_widget_close (emb->bvw);
+	totem_embedded_clear_playlist (emb, NULL);
 
 	totem_embedded_set_uri (emb, uri, base_uri, TRUE);
 	/* We can only have one item in the "playlist" when
@@ -1044,7 +1181,7 @@ totem_embedded_set_local_file (TotemEmbedded *emb,
 
 	g_message ("Setting the current path to %s", path);
 
-	totem_embedded_clear_playlist (emb);
+	totem_embedded_clear_playlist (emb, NULL);
 
 	file_uri = g_filename_to_uri (path, NULL, error);
 	if (!file_uri)
@@ -1090,7 +1227,7 @@ totem_embedded_set_playlist (TotemEmbedded *emb,
 	g_message ("Setting the current playlist to %s (base: %s)",
 		   path, base_uri);
 
-	totem_embedded_clear_playlist (emb);
+	totem_embedded_clear_playlist (emb, NULL);
 
 	file_uri = g_filename_to_uri (path, NULL, error);
 	if (!file_uri)
@@ -1123,21 +1260,27 @@ totem_embedded_update_menu (TotemEmbedded *emb)
 		emb->app = NULL;
 	}
 
-	if (emb->mimetype) {
+	if (emb->mimetype && strcmp (emb->mimetype, "application/octet-stream") != 0) {
 		emb->app = gnome_vfs_mime_get_default_application_for_uri
 				(emb->current_uri, emb->mimetype);
 	} else {
+		const char *uri;
+
+		/* If we're reading a local file, that's not a playlist,
+		 * we need to use that to get its proper mime-type */
+		if (emb->stream_uri != NULL)
+			uri = emb->stream_uri;
+		else
+			uri = emb->current_uri;
 		emb->app = gnome_vfs_mime_get_default_application_for_uri
-				(emb->current_uri,
-				 gnome_vfs_get_mime_type_for_name (emb->current_uri));
+				(uri, gnome_vfs_get_mime_type_for_name (uri));
 	}
 
 	if (emb->app == NULL) {
-
 		if (emb->mimetype != NULL) {
-			g_warning ("Mimetype '%s' doesn't have a handler", emb->mimetype);
+			g_message ("Mimetype '%s' doesn't have a handler", emb->mimetype);
 		} else {
-			g_warning ("No handler for URI '%s' (guessed mime-type '%s')",
+			g_message ("No handler for URI '%s' (guessed mime-type '%s')",
 				   emb->current_uri,
 				   gnome_vfs_get_mime_type_for_name (emb->current_uri));
 		}
@@ -1355,78 +1498,73 @@ on_popup_button_button_pressed (GtkToggleButton *button,
 	return FALSE;
 }
 
+static char *
+resolve_redirect (const char *old_mrl, const char *mrl)
+{
+	GFile *old_file, *parent, *new_file;
+	char *retval;
+
+	/* Get the parent for the current MRL, that's our base */
+	old_file = g_file_new_for_uri (old_mrl);
+	parent = g_file_get_parent (old_file);
+	g_object_unref (old_file);
+
+	/* Resolve the URL */
+	new_file = g_file_get_child (parent, mrl);
+	g_object_unref (parent);
+
+	retval = g_file_get_uri (new_file);
+	g_object_unref (new_file);
+
+	return retval;
+}
+
 static void
 on_got_redirect (GtkWidget *bvw, const char *mrl, TotemEmbedded *emb)
 {
-	char *new_uri = NULL;
+	char *new_uri;
 
-	g_message ("url: %s", emb->base_uri);
+	g_message ("stream uri: %s", emb->stream_uri ? emb->stream_uri : "(null)");
+	g_message ("current uri: %s", emb->current_uri ? emb->current_uri : "(null)");
+	g_message ("base uri: %s", emb->base_uri ? emb->base_uri : "(null)");
 	g_message ("redirect: %s", mrl);
 
 	bacon_video_widget_close (emb->bvw);
 
+	/* If we don't have a relative URI */
+	if (strstr (mrl, "://") != NULL)
+		new_uri = NULL;
 	/* We are using a local cache, so we resolve against the stream_uri */
 	if (emb->stream_uri)
-		new_uri = totem_pl_parser_resolve_url (emb->stream_uri, mrl);
+		new_uri = resolve_redirect (emb->stream_uri, mrl);
 	/* We don't have a local cache, so resolve against the URI */
 	else if (emb->current_uri)
-		new_uri = totem_pl_parser_resolve_url (emb->current_uri, mrl);
+		new_uri = resolve_redirect (emb->current_uri, mrl);
 	/* FIXME: not sure that this is actually correct... */
 	else if (emb->base_uri)
-		new_uri = totem_pl_parser_resolve_url (emb->base_uri, mrl);
+		new_uri = resolve_redirect (emb->base_uri, mrl);
 
-	if (!new_uri)
-		return;
-
-	g_message ("Redirecting to '%s'", new_uri);
+	g_message ("Redirecting to '%s'", new_uri ? new_uri : mrl);
 
 	/* FIXME: clear playlist? or replace current entry? or add a new entry? */
 	/* FIXME: use totem_embedded_open_uri? */
 
-	totem_embedded_set_uri (emb, new_uri, emb->base_uri /* FIXME? */, FALSE);
+	totem_embedded_set_uri (emb, new_uri ? new_uri : mrl , emb->base_uri /* FIXME? */, FALSE);
 
 	totem_embedded_set_state (emb, TOTEM_STATE_STOPPED);
 
 	totem_embedded_open_internal (emb, TRUE, NULL /* FIXME? */);
+
+	g_free (new_uri);
 }
 
 static void
 totem_embedded_toggle_fullscreen (TotemEmbedded *emb)
 {
-	GtkAction * fs_action = GTK_ACTION (gtk_builder_get_object 
-					    (emb->menuxml, "fullscreen1"));
-
 	if (totem_fullscreen_is_fullscreen (emb->fs) != FALSE)
-	{
-		GtkWidget * container;
-		container = GTK_WIDGET (gtk_builder_get_object (emb->xml,
-								"video_box"));
-
-		totem_fullscreen_set_fullscreen (emb->fs, FALSE);
-		gtk_widget_reparent (GTK_WIDGET (emb->bvw), container);
-		gtk_widget_hide_all (emb->fs_window);
-		
-		gtk_action_set_sensitive (fs_action, TRUE);
-	} else {
-		GdkRectangle rect;
-		int monitor;
-
-		/* Move the fullscreen window to the screen where the
-		 * video widget currently is */
-		monitor = gdk_screen_get_monitor_at_window (gtk_widget_get_screen (GTK_WIDGET (emb->bvw)),
-							    GTK_WIDGET (emb->bvw)->window);
-		gdk_screen_get_monitor_geometry (gtk_widget_get_screen (GTK_WIDGET (emb->bvw)),
-						 monitor, &rect);
-		gtk_window_move (GTK_WINDOW (emb->fs_window), rect.x, rect.y);
-
-		gtk_widget_reparent (GTK_WIDGET (emb->bvw), emb->fs_window);
-		bacon_video_widget_set_fullscreen (emb->bvw, TRUE);
-		gtk_window_fullscreen (GTK_WINDOW (emb->fs_window));
-		totem_fullscreen_set_fullscreen (emb->fs, TRUE);
-		gtk_widget_show_all (emb->fs_window);
-
-		gtk_action_set_sensitive (fs_action, FALSE);
-	}
+		totem_embedded_set_fullscreen (emb, FALSE, NULL);
+	else
+		totem_embedded_set_fullscreen (emb, TRUE, NULL);
 }
 
 static void
@@ -1450,7 +1588,11 @@ on_video_button_press_event (BaconVideoWidget *bvw,
 	menu = GTK_MENU (gtk_builder_get_object (emb->menuxml, "menu"));
 
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1 && state == 0 && emb->state == TOTEM_STATE_STOPPED) {
-		if (!GTK_WIDGET_VISIBLE (menu)) {
+		if (emb->error != NULL) {
+			totem_interface_error (_("An error occurred"), emb->error->message, (GtkWindow *) (emb->window));
+			g_error_free (emb->error);
+			emb->error = NULL;
+		} else if (!GTK_WIDGET_VISIBLE (menu)) {
 			g_message ("emitting signal");
 			g_signal_emit (emb, signals[BUTTON_PRESS], 0,
 				       event->time,
@@ -1559,13 +1701,15 @@ on_error_event (BaconVideoWidget *bvw,
 		exit (1);
 	}
 
-	totem_embedded_set_error (emb, _("An error occurred"), message);
+	totem_embedded_set_error (emb, BVW_ERROR_GENERIC, message);
+	totem_embedded_set_error_logo (emb, NULL);
 }
 
 static void
 cb_vol (GtkWidget *val, gdouble value, TotemEmbedded *emb)
 {
 	bacon_video_widget_set_volume (emb->bvw, value);
+	totem_embedded_save_volume (emb, value);
 }
 
 static void
@@ -1597,7 +1741,9 @@ on_tick (GtkWidget *bvw,
 	}
 
 	g_signal_emit (emb, signals[SIGNAL_TICK], 0,
-		       (guint32) current_time, (guint32) stream_length, totem_states[emb->state]);
+		       (guint32) current_time,
+		       (guint32) stream_length,
+		       totem_states[emb->state]);
 }
 
 static void
@@ -1664,6 +1810,7 @@ totem_embedded_action_volume_relative (TotemEmbedded *emb, double off_pct)
 	
 	vol = bacon_video_widget_get_volume (emb->bvw);
 	bacon_video_widget_set_volume (emb->bvw, vol + off_pct);
+	totem_embedded_save_volume (emb, vol + off_pct);
 }
 
 static gboolean
@@ -1876,6 +2023,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 	g_signal_connect (G_OBJECT (emb->volume), "value-changed",
 			  G_CALLBACK (cb_vol), emb);
 	bacon_video_widget_set_volume (emb->bvw, volume);
+	totem_embedded_save_volume (emb, volume);
 
 	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (emb->statusbar), FALSE);
@@ -2034,28 +2182,6 @@ totem_embedded_unset_window (TotemEmbedded *embedded,
 	return TRUE;
 }
 
-static void
-totem_pl_item_free (gpointer data, gpointer user_data)
-{
-	TotemPlItem *item = (TotemPlItem *) data;
-
-	if (!item)
-		return;
-	g_free (item->uri);
-	g_free (item);
-}
-
-static void
-totem_embedded_clear_playlist (TotemEmbedded *embedded)
-{
-	g_list_foreach (embedded->playlist, (GFunc) totem_pl_item_free, NULL);
-	g_list_free (embedded->playlist);
-
-	embedded->playlist = NULL;
-	embedded->current = NULL;
-	embedded->num_items = 0;
-}
-
 static void
 entry_metadata_foreach (const char *key,
 			const char *value,
@@ -2074,6 +2200,7 @@ entry_parsed (TotemPlParser *parser,
 {
 	TotemEmbedded *emb = (TotemEmbedded *) data;
 	TotemPlItem *item;
+	int duration;
 
 	if (g_str_has_prefix (uri, "file://") != FALSE
 	    && g_str_has_prefix (emb->base_uri, "file://") == FALSE) {
@@ -2084,9 +2211,14 @@ entry_parsed (TotemPlParser *parser,
 	g_print ("added URI '%s'\n", uri);
 	g_hash_table_foreach (metadata, (GHFunc) entry_metadata_foreach, NULL);
 
+	/* Skip short advert streams */
+	duration = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "duration"), FALSE);
+	if (duration == 0)
+		return;
+
 	item = g_new0 (TotemPlItem, 1);
 	item->uri = g_strdup (uri);
-	item->duration = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "duration"), FALSE);
+	item->duration = duration;
 	item->starttime = totem_pl_parser_parse_duration (g_hash_table_lookup (metadata, "starttime"), FALSE);
 
 	emb->playlist = g_list_prepend (emb->playlist, item);
@@ -2100,7 +2232,6 @@ totem_embedded_push_parser (gpointer data)
 	TotemPlParserResult res;
 
 	emb->parser_id = 0;
-	totem_embedded_clear_playlist (emb);
 
 	parser = totem_pl_parser_new ();
 	g_object_set (parser, "force", TRUE,
@@ -2132,9 +2263,9 @@ totem_embedded_push_parser (gpointer data)
 	/* Check if we have anything in the playlist now */
 	if (emb->playlist == NULL && res != TOTEM_PL_PARSER_RESULT_SUCCESS) {
 		g_message ("Couldn't parse playlist '%s'", emb->current_uri);
-		totem_embedded_set_error (emb, _("No playlist or playlist empty") /* FIXME */,
-					  NULL);
-		totem_embedded_set_logo_by_name (emb, "image-missing");
+		totem_embedded_set_error (emb, BVW_ERROR_EMPTY_FILE,
+					  _("No playlist or playlist empty"));
+		totem_embedded_set_error_logo (emb, NULL);
 		return FALSE;
 	} else if (emb->playlist == NULL) {
 		g_message ("Playlist empty");
