@@ -15,10 +15,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  *
- * $Id: totemComplexPlugin.h 5065 2008-02-04 14:32:50Z hadess $
+ * $Id: totemComplexPlugin.h 5373 2008-04-24 15:28:08Z hadess $
  */
 
 #ifndef __COMPLEX_PLUGIN_H__
@@ -53,7 +53,6 @@ class totemScriptablePlugin : public totemIComplexPlayer,
     totemPlugin *mPlugin;
 
     PRInt32 mNumLoops;
-    PRInt32 mVolume;
 
     nsCString mAuthor;
     nsCString mBackgroundColour;
