@@ -16,10 +16,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  *
- * $Id: totemGMPPlugin.cpp 5108 2008-02-12 01:55:51Z hadess $
+ * $Id: totemGMPPlugin.cpp 5401 2008-05-09 09:50:30Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -67,6 +67,7 @@ static const totemPluginMimeEntry kMimeTypes[] = {
 	{ "video/x-wmv", "wmv", "video/x-ms-wmv" },
 	{ "video/x-ms-wvx", "wmv", "video/x-ms-wmv" },
 	{ "video/x-ms-wm", "wmv", "video/x-ms-wmv" },
+	{ "video/x-ms-wmp", "wmv", "video/x-ms-wmv" },
 	{ "application/x-ms-wms", "wms", "video/x-ms-wmv" },
 	{ "application/asx", "asx", "audio/x-ms-asx" },
 	{ "audio/x-ms-wma", "wma", NULL }
