@@ -16,10 +16,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  *
- * $Id: totemGMPPlugin.h 4845 2007-11-01 16:05:27Z hadess $
+ * $Id: totemGMPPlugin.h 5373 2008-04-24 15:28:08Z hadess $
  */
 
 #ifndef __GMP_PLUGIN_H__
@@ -53,6 +53,7 @@ class totemScriptablePlugin : public totemIGMPPlayer,
     void SetPlugin (totemPlugin *aPlugin) { mPlugin = aPlugin; }
 
     static char *PluginDescription ();
+    static char *PluginLongDescription();
     static void PluginMimeTypes (const totemPluginMimeEntry **, PRUint32 *);
   private:
     friend class totemGMPSettings;
