@@ -13,14 +13,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -28,13 +28,13 @@
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
 #define HAVE_BACON_VIDEO_WIDGET_H
 
-#include <gtk/gtkbox.h>
-
+#include <gtk/gtkeventbox.h>
 /* for optical disc enumeration type */
-#include "totem-disc.h"
+#include <totem-disc.h>
 
 G_BEGIN_DECLS
 
+#define BACON_TYPE_VIDEO_WIDGET		     (bacon_video_widget_get_type ())
 #define BACON_VIDEO_WIDGET(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), bacon_video_widget_get_type (), BaconVideoWidget))
 #define BACON_VIDEO_WIDGET_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), bacon_video_widget_get_type (), BaconVideoWidgetClass))
 #define BACON_IS_VIDEO_WIDGET(obj)           (G_TYPE_CHECK_INSTANCE_TYPE (obj, bacon_video_widget_get_type ()))
@@ -45,13 +45,13 @@ typedef struct BaconVideoWidgetPrivate BaconVideoWidgetPrivate;
 typedef struct BaconVideoWidgetCommon BaconVideoWidgetCommon;
 
 typedef struct {
-	GtkBox parent;
+	GtkEventBox parent;
 	BaconVideoWidgetCommon *com;
 	BaconVideoWidgetPrivate *priv;
 } BaconVideoWidget;
 
 typedef struct {
-	GtkBoxClass parent_class;
+	GtkEventBoxClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message,
                        gboolean playback_stopped, gboolean fatal);
@@ -61,7 +61,7 @@ typedef struct {
 	void (*title_change) (GtkWidget *bvw, const char *title);
 	void (*channels_change) (GtkWidget *bvw);
 	void (*tick) (GtkWidget *bvw, gint64 current_time, gint64 stream_length,
-			float current_position, gboolean seekable);
+			double current_position, gboolean seekable);
 	void (*buffering) (GtkWidget *bvw, guint progress);
 } BaconVideoWidgetClass;
 
@@ -128,13 +128,13 @@ gboolean bacon_video_widget_is_playing           (BaconVideoWidget *bvw);
 /* Seeking and length */
 gboolean bacon_video_widget_is_seekable          (BaconVideoWidget *bvw);
 gboolean bacon_video_widget_seek		 (BaconVideoWidget *bvw,
-						  float position,
+						  double position,
 						  GError **error);
 gboolean bacon_video_widget_seek_time		 (BaconVideoWidget *bvw,
 						  gint64 time,
 						  GError **error);
 gboolean bacon_video_widget_can_direct_seek	 (BaconVideoWidget *bvw);
-float bacon_video_widget_get_position            (BaconVideoWidget *bvw);
+double bacon_video_widget_get_position           (BaconVideoWidget *bvw);
 gint64 bacon_video_widget_get_current_time       (BaconVideoWidget *bvw);
 gint64 bacon_video_widget_get_stream_length      (BaconVideoWidget *bvw);
 
@@ -144,8 +144,8 @@ void bacon_video_widget_close                    (BaconVideoWidget *bvw);
 /* Audio volume */
 gboolean bacon_video_widget_can_set_volume       (BaconVideoWidget *bvw);
 void bacon_video_widget_set_volume               (BaconVideoWidget *bvw,
-						  int volume);
-int bacon_video_widget_get_volume                (BaconVideoWidget *bvw);
+						  double volume);
+double bacon_video_widget_get_volume             (BaconVideoWidget *bvw);
 
 /* Properties */
 void bacon_video_widget_set_logo		 (BaconVideoWidget *bvw,
@@ -171,26 +171,31 @@ void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
 
-void bacon_video_widget_set_media_device         (BaconVideoWidget *bvw,
-						  const char *path);
-gboolean bacon_video_widget_can_play             (BaconVideoWidget *bvw,
-						  MediaType type);
+typedef enum {
+	BVW_CAN_PLAY_SUCCESS,
+	BVW_CAN_PLAY_MISSING_CHANNELS,
+	BVW_CAN_PLAY_MISSING_PLUGINS,
+	BVW_CAN_PLAY_UNSUPPORTED
+} BaconVideoWidgetCanPlayStatus;
+
+BaconVideoWidgetCanPlayStatus bacon_video_widget_can_play
+						 (BaconVideoWidget *bvw,
+						  TotemDiscMediaType type);
+
 gchar **bacon_video_widget_get_mrls		 (BaconVideoWidget *bvw,
-						  MediaType type);
+						  TotemDiscMediaType type,
+						  const char *device);
 void bacon_video_widget_set_subtitle_font	 (BaconVideoWidget *bvw,
 						  const char *font);
 void bacon_video_widget_set_subtitle_encoding	 (BaconVideoWidget *bvw,
 						  const char *encoding);
 
-/* Video devices */
-void bacon_video_widget_set_video_device	 (BaconVideoWidget *bvw,
-						  const char *path);
-
 /* Metadata */
 typedef enum {
 	BVW_INFO_TITLE,
 	BVW_INFO_ARTIST,
 	BVW_INFO_YEAR,
+	BVW_INFO_COMMENT,
 	BVW_INFO_ALBUM,
 	BVW_INFO_DURATION,
 	BVW_INFO_TRACK_NUMBER,
@@ -240,11 +245,11 @@ typedef enum {
 } BaconVideoWidgetVideoProperty;
 
 typedef enum {
-	BVW_RATIO_AUTO,
-	BVW_RATIO_SQUARE,
-	BVW_RATIO_FOURBYTHREE,
-	BVW_RATIO_ANAMORPHIC,
-	BVW_RATIO_DVB
+	BVW_RATIO_AUTO = 0,
+	BVW_RATIO_SQUARE = 1,
+	BVW_RATIO_FOURBYTHREE = 2,
+	BVW_RATIO_ANAMORPHIC = 3,
+	BVW_RATIO_DVB = 4
 } BaconVideoWidgetAspectRatio;
 
 void bacon_video_widget_set_deinterlacing        (BaconVideoWidget *bvw,
