@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -39,7 +39,6 @@
 #ifndef HAVE_GTK_ONLY
 #include <libgnomeui/gnome-authentication-manager.h>
 #endif
-#include <libgnomevfs/gnome-vfs-init.h>
 #include "bacon-video-widget.h"
 #include "totem-resources.h"
 
@@ -312,10 +311,10 @@ save_pixbuf (GdkPixbuf *pixbuf, const char *path,
 
 		if (err != NULL)
 		{
-			g_print ("totem-video-thumbnailer couln't write the thumbnail '%s' for video '%s': %s\n", path, video_path, err->message);
+			g_print ("totem-video-thumbnailer couldn't write the thumbnail '%s' for video '%s': %s\n", path, video_path, err->message);
 			g_error_free (err);
 		} else {
-			g_print ("totem-video-thumbnailer couln't write the thumbnail '%s' for video '%s'\n", path, video_path);
+			g_print ("totem-video-thumbnailer couldn't write the thumbnail '%s' for video '%s'\n", path, video_path);
 		}
 
 		g_object_unref (with_holes);
@@ -335,7 +334,7 @@ capture_interesting_frame (BaconVideoWidget * bvw, char *input, char *output)
 	GdkPixbuf* pixbuf;
 	guint current;
 	GError *err = NULL;
-	const float frame_locations[] = {
+	const double frame_locations[] = {
 		1.0 / 3.0,
 		2.0 / 3.0,
 		0.1,
@@ -349,6 +348,7 @@ capture_interesting_frame (BaconVideoWidget * bvw, char *input, char *output)
 	{
 		PROGRESS_DEBUG("About to seek to %f\n", frame_locations[current]);
 		if (bacon_video_widget_seek (bvw, frame_locations[current], NULL) == FALSE) {
+			PROGRESS_DEBUG("Couldn't seek to %f\n", frame_locations[current]);
 			bacon_video_widget_play (bvw, NULL);
 		}
 
@@ -469,8 +469,6 @@ int main (int argc, char *argv[])
 	}
 #endif /* THUMB_DEBUG */
 
-	gnome_vfs_init ();
-
 #ifndef HAVE_GTK_ONLY
 	gnome_authentication_manager_init ();
 #endif
@@ -485,9 +483,8 @@ int main (int argc, char *argv[])
 	PROGRESS_DEBUG("Initialised libraries, about to create video widget\n");
 
 	bvw = BACON_VIDEO_WIDGET (bacon_video_widget_new (-1, -1, BVW_USE_TYPE_CAPTURE, &err));
-	if (err != NULL)
-	{
-		g_print ("totem-video-thumbnailer couln't create the video "
+	if (err != NULL) {
+		g_print ("totem-video-thumbnailer couldn't create the video "
 				"widget.\nReason: %s.\n", err->message);
 		g_error_free (err);
 		exit (1);
@@ -500,9 +497,8 @@ int main (int argc, char *argv[])
 
 	PROGRESS_DEBUG("About to open video file\n");
 
-	if (bacon_video_widget_open (bvw, input, &err) == FALSE)
-	{
-		g_print ("totem-video-thumbnailer couln't open file '%s'\n"
+	if (bacon_video_widget_open (bvw, input, &err) == FALSE) {
+		g_print ("totem-video-thumbnailer couldn't open file '%s'\n"
 				"Reason: %s.\n",
 				input, err->message);
 		g_error_free (err);
@@ -513,9 +509,8 @@ int main (int argc, char *argv[])
 	PROGRESS_DEBUG("About to play file\n");
 
 	bacon_video_widget_play (bvw, &err);
-	if (err != NULL)
-	{
-		g_print ("totem-video-thumbnailer couln't play file: '%s'\n"
+	if (err != NULL) {
+		g_print ("totem-video-thumbnailer couldn't play file: '%s'\n"
 				"Reason: %s.\n", input, err->message);
 		g_error_free (err);
 		exit (1);
@@ -526,20 +521,18 @@ int main (int argc, char *argv[])
 	/* If the user has told us to use a frame at a specific second 
 	 * into the video, just use that frame no matter how boring it
 	 * is */
-	if(-1 != second_index) {
-	  pixbuf = capture_frame_at_time(bvw, input, output, second_index);
-	} else {
-	  pixbuf = capture_interesting_frame(bvw, input, output);
-	}
+	if(second_index != -1)
+		pixbuf = capture_frame_at_time (bvw, input, output, second_index);
+	else
+		pixbuf = capture_interesting_frame (bvw, input, output);
 
 	/* Cleanup */
 	bacon_video_widget_close (bvw);
 	totem_resources_monitor_stop ();
 	gtk_widget_destroy (GTK_WIDGET (bvw));
 
-	if (pixbuf == NULL)
-	{
-		g_print ("totem-video-thumbnailer couln't get a picture from "
+	if (pixbuf == NULL) {
+		g_print ("totem-video-thumbnailer couldn't get a picture from "
 					"'%s'\n", input);
 		exit (1);
 	}
