@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -121,6 +121,21 @@ long_action (void)
 		gtk_main_iteration ();
 }
 
+static void
+reset_seek_status (Totem *totem)
+{
+	/* Release the lock and reset everything so that we
+	 * avoid being "stuck" seeking on errors */
+
+	if (totem->seek_lock != FALSE) {
+		totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), FALSE);
+		totem_time_label_set_seeking (TOTEM_TIME_LABEL (totem->fs->time_label), FALSE);
+		totem->seek_lock = FALSE;
+		bacon_video_widget_seek (totem->bvw, 0, NULL);
+		totem_action_stop (totem);
+	}
+}
+
 /**
  * totem_action_error:
  * @title: the error dialog title
@@ -133,6 +148,7 @@ long_action (void)
 void
 totem_action_error (const char *title, const char *reason, Totem *totem)
 {
+	reset_seek_status (totem);
 	totem_interface_error (title, reason,
 			GTK_WINDOW (totem->win));
 }
@@ -141,6 +157,7 @@ static void
 totem_action_error_and_exit (const char *title,
 		const char *reason, Totem *totem)
 {
+	reset_seek_status (totem);
 	totem_interface_error_blocking (title, reason,
 			GTK_WINDOW (totem->win));
 	totem_action_exit (totem);
@@ -439,13 +456,7 @@ totem_action_seek (Totem *totem, double pos)
 		msg = g_strdup_printf(_("Totem could not play '%s'."), disp);
 		g_free (disp);
 
-		/* Release the lock and reset everything so that we
-		 * avoid being "stuck" seeking */
-		totem_statusbar_set_seeking (TOTEM_STATUSBAR (totem->statusbar), FALSE);
-		totem_time_label_set_seeking (TOTEM_TIME_LABEL (totem->fs->time_label), FALSE);
-		totem->seek_lock = FALSE;
-		bacon_video_widget_seek (totem->bvw, 0, NULL);
-		totem_action_stop (totem);
+		reset_seek_status (totem);
 
 		totem_action_error (msg, err->message, totem);
 		g_free (msg);
@@ -1587,17 +1598,34 @@ drag_video_cb (GtkWidget *widget,
 static void
 on_got_redirect (BaconVideoWidget *bvw, const char *mrl, Totem *totem)
 {
-	gchar *old_mrl, *new_mrl;
+	char *new_mrl;
 
-	old_mrl = totem_playlist_get_current_mrl (TOTEM_PLAYLIST (totem->playlist), NULL);
-	new_mrl = totem_pl_parser_resolve_url (old_mrl, mrl);
-	g_free (old_mrl);
+	if (strstr (mrl, "://") != NULL) {
+		new_mrl = NULL;
+	} else {
+		GFile *old_file, *parent, *new_file;
+		char *old_mrl;
+
+		/* Get the parent for the current MRL, that's our base */
+		old_mrl = totem_playlist_get_current_mrl (TOTEM_PLAYLIST (totem->playlist), NULL);
+		old_file = g_file_new_for_uri (old_mrl);
+		g_free (old_mrl);
+		parent = g_file_get_parent (old_file);
+		g_object_unref (old_file);
+
+		/* Resolve the URL */
+		new_file = g_file_get_child (parent, mrl);
+		g_object_unref (parent);
+
+		new_mrl = g_file_get_uri (new_file);
+		g_object_unref (new_file);
+	}
 
 	bacon_video_widget_close (totem->bvw);
 	totem_file_closed (totem);
 	totem_gdk_window_set_waiting_cursor (totem->win->window);
-	bacon_video_widget_open (totem->bvw, new_mrl, NULL);
-	totem_file_opened (totem, new_mrl);
+	bacon_video_widget_open (totem->bvw, new_mrl ? new_mrl : mrl, NULL);
+	totem_file_opened (totem, new_mrl ? new_mrl : mrl);
 	gdk_window_set_cursor (totem->win->window, NULL);
 	bacon_video_widget_play (bvw, NULL);
 	g_free (new_mrl);
